import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

const originalPush = Router.prototype.push;
Router.prototype.push = function (location) {
    originalPush.call(this, location).catch((err) => err);
};
const originalReplace = Router.prototype.replace;
Router.prototype.replace = function (location) {
    originalReplace.call(this, location).catch((err) => err);
};

/* AppLayout */
import AppLayout from "@/layout/app/index.vue";

/* MainDefaultLayout */
import MainDefaultLayout from "@/layout/main/default/index.vue";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * allRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const allRoutes = [
    {
        path: "/404",
        component: () => import("@/views/404.vue"),
        hidden: true,
    },
    {
        path: "/",
        redirect: "/zhxy/nbtz",
    },
    {
        path: "/zhxy",
        name: "zhxy",
        component: AppLayout,
        meta: {title: "智慧校园", icon: "el-icon-document"},
        children: [
            {
                path: "/zhxy/nbtz",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_nbtz",
                        meta: {title: "内部通知"},
                        component: () => import("@/views/xxzx/index.vue"),
                        props: true,
                    },
                    {
                        path: "nbtz_detail/:id",
                        hidden: true,
                        name: "zhxy_nbtz_detail",
                        component: () => import("@/views/zhxy/nbtz/detail.vue"),
                        meta: {title: "通知详情"},
                        props: true,
                    },
                ],
            },
            {
                path: "yzgz",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_yzgz",
                        component: () => import("@/views/cfbtsb/gzt/index.vue"),
                        meta: {title: "一周工作"},
                        props: true,
                    },
                    {
                        path: "yzgz_ck/:id",
                        hidden: true,
                        name: "zhxy_yzgz_ck",
                        component: () => import("@/views/zhxy/yzgz/seeAbout.vue"),
                        meta: {title: "查看"},
                        props: true,
                    },
                ],
            },
            {
                path: "zrhd",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_zrhd",
                        meta: {title: "值日护导"},
                        component: () => import("@/views/zrhd/index.vue"),
                        props: true,
                    },
                ],
            },
            {
                path: "gwgl",
                component: MainDefaultLayout,
                children: [

                    {
                        path: "",
                        meta: {title: "计划总结"},
                        name: "gwgl_gwgd",
                        props: true,
                        component: () => import("@/views/gwgl/gwgd/index.vue"),
                    },
                    {
                        path: "gwgdgg",
                        hidden: true,
                        meta: {title: "计划总结列表"},
                        name: "gwgdgg",
                        component: () => import("@/views/gwgl/gwgdgg/index.vue"),
                    },
                    {
                        title: "公文下达",
                        path: "gwxd",
                        hidden: true,
                        meta: {title: "公文下达"},
                        name: "gwxd",
                        component: () => import("@/views/gwgl/gwxd/index.vue"),
                    },
                    {
                        title: "未办公文",
                        path: "wbgw",
                        hidden: true,
                        meta: {title: "未办公文"},
                        name: "wbgw",
                        component: () => import("@/views/gwgl/wbgw/index.vue"),
                    },
                ]
            },
            {
                path: "zxxx",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_zxxx",
                        meta: {title: "在线消息"},
                        component: () => import("@/views/zxxx/index.vue"),
                        props: true,
                    },
                ],
            },
            {
                path: "dbsx",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_dbsx",
                        meta: {title: "待办事项"},
                        component: () => import("@/views/gwgl/gzt/index.vue"),
                        props: true,
                    },
                ],
            },
            {
                path: "swgl",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_swgl",
                        meta: {title: "事务管理"},
                        component: () => import("@/views/swgl/index.vue"),
                        props: true,
                    },
                ],
            },
            {
                path: '/xzfw',
                component: MainDefaultLayout,
                name: 'zhxy_xzfw',
                meta: { title: '行政服务'},
                children: [
                    {
                        path: "qjgl",
                        hidden: false,
                        meta: { title: "请假管理"},
                        name: "qjgl",
                        component: () =>import ('@/views/xzfw/qjgl/index.vue'),
                    },
                    {
                        path: "lxgl",
                        hidden: false,
                        meta: { title: "离校管理"},
                        name: "lxgl",
                        component: () =>import ('@/views/xzfw/lxgl/index.vue'),
                    },
                    {
                        path: "wcgl",
                        hidden: false,
                        meta: {title: "外出管理"},
                        name: "wcgl",
                        component: () =>import ('@/views/xzfw/wcgl/index.vue'),
                    }
                ]
            },
            {
                path: "/hysydgl",
                component: MainDefaultLayout,
                redirect: "/hysydgl/hysyd",
                name: "hysydgl",
                meta: { title: "会议管理"},
                children: [{
                    path: "hysyd",
                    // name: 'zzjg',
                    component: () => import("@/views/hysydgl/hysyd/index.vue"),
                    meta: { title: "会议室预定" }
                }, {
                    path: 'hysyd_detail/:yd_id',
                    name: 'hysyd_detail',
                    component: () => import("@/views/hysydgl/hysyd/detail.vue"),
                }, {
                    path: "hyjy",
                    // name: 'zzjg',
                    component: () => import("@/views/hysydgl/hyjy/index.vue"),
                    meta: { title: "会议纪要" }
                }, {
                    path: 'hyjy_detail/:hyjy_id',
                    name: 'hyjy_detail',
                    component: () => import("@/views/hysydgl/hyjy/detail.vue")
                }, {
                    path: "hyjyk",
                    // name: 'zzjg',
                    component: () => import("@/views/hysydgl/hyjyk/index.vue"),
                    meta: { title: "会议纪要库" }
                }, {
                    path: "hysgl",
                    // name: 'zzjg',
                    component: () => import("@/views/hysydgl/hysgl/index.vue"),
                    meta: { title: "会议室管理" }
                },  {
                    path: "bbtj",
                    // name: 'zzjg',
                    component: MainDefaultLayout,
                    children: [
                        {
                            path: "",
                            name: 'hysyd_bbtj',
                            component: () => import("@/views/hysydgl/bbtj/index.vue"),
                            meta: { title: "报表统计" },
                            props: true
                        }, {
                            path: "bbxq/:bb_id",
                            hidden: true,
                            name: "hysyd_bbtj_bbxq",
                            component: () => import("@/views/hysydgl/bbtj/detail.vue"),
                            meta: { title: "报表详情" },
                            props: true
                        }]
                },]
            },
            {
                path: "hgjc",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_hgjc",
                        meta: {title: "行规检查"},
                        component: () => import("@/views/hgjc/index.vue"),
                        props: true,
                    },
                ],
            },
            {
                path: "xjglxt",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_xjglxt",
                        meta: {title: "学籍管理系统"},
                        component: () => import("@/views/xsydlb/index.vue"),
                        props: true,
                    },
                ],
            },
            {
                path: "xyglxt",
                component: MainDefaultLayout,
                children: [
                    {
                        path: "",
                        name: "zhxy_xyglxt",
                        meta: {title: "学业管理系统"},
                        component: () => import("@/views/xyglxt/index.vue"),
                        props: true,
                    },
                ],
            },
        ],
    },
    {
        path: "/kzkt",
        component: AppLayout,
        name: "kzkt",
        meta: {title: "空中课堂", icon: "el-icon-document"},
        children: [
            {
                path: "",
                // name: 'zzjg',
                component: () => import("@/views/kzkt/index.vue"),
                meta: {title: "空中课堂"},
            },
        ],
    },
    {
        path: "/zhkt",
        component: AppLayout,
        name: "zhkt",
        meta: {title: "智慧课堂", icon: "el-icon-document"},
        children: [
            {
                path: "",
                // name: 'zzjg',
                component: () => import("@/views/zhkt/index.vue"),
                meta: {title: "智慧课堂"},
            },
        ],
    },
    {
        path: "/pkxk",
        component: AppLayout,
        name: "pkxk",
        meta: {title: "排课选课", icon: "el-icon-document"},
        children: [
            {
                path: "",
                name: 'pkxk_bjgl',
                component: () => import("@/views/pkxk/bjgl/index.vue"),
                meta: {title: "班级管理"},
            },
            {
                path: "kcgl",
                name: 'pkxk_kcgl',
                component: () => import("@/views/pkxk/kcgl/index.vue"),
                meta: {title: "课程管理"},
            },
            {
                path: "xqgl",
                name: 'pkxk_xqgl',
                component: () => import("@/views/pkxk/xqgl/index.vue"),
                meta: {title: "学期管理"},
            },
            {
                path: "xkgl",
                name: 'pkxk_xkgl',
                component: () => import("@/views/pkxk/xkgl/index.vue"),
                meta: {title: "选课管理"},
            },
            {
                path: "kcb",
                name: 'pkxk_kcb',
                component: () => import("@/views/pkxk/kcb/index.vue"),
                meta: {title: "课程表"},
            },
        ],
    },
    {
        path: "/zsgl",
        component: AppLayout,
        redirect: "/zsgl/zsgg",
        name: "zsgl",
        meta: {title: "招生管理", icon: "el-icon-document"},
        children: [
            {
                path: "zsgg",
                // name: 'zzjg',
                component: () => import("@/views/zsgl/zsgg/index.vue"),
                meta: {title: "招生公告"},
            },
            {
                path: "zsxxsh",
                name: "zsgl_zsxxsh",
                component: () => import("@/views/zsgl/zsxxsh/index.vue"),
                meta: {title: "招生信息审核"},
                props: true,
            },
            {
                path: "dzbgd",
                name: "zsgl_dzbgd",
                component: () => import("@/views/zsgl/dzbgd/index.vue"),
                meta: {title: "电子报告单"},
                props: true,
            },

        ],
    },
    {
        path: "/dcwj",
        component: AppLayout,
        name: "dcwj",
        meta: {title: "调查问卷", icon: "el-icon-document"},
        children: [
            {
                path: "",
                // name: 'zzjg',
                component: () => import("@/views/dcwj/index.vue"),
                meta: {title: "调查问卷"},
            },
        ],
    },
    // {
    //   path: "/jsld",
    //   component: AppLayout,
    //   redirect: "/jsld/gzt",
    //   name: "jsld",
    //   meta: { title: "教师流动管理", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "gzt",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jsld/gzt/index.vue"),
    //       meta: { title: "工作台" },
    //     },
    //     {
    //       path: "lcgl",
    //       name: "jsld_lcgl",
    //       component: () => import("@/views/jsld/lcgl/index.vue"),
    //       meta: { title: "流程管理" },
    //     },
    //     {
    //       path: "rzlc",
    //       component: MainDefaultLayout,
    //       meta: { title: "入职流程" },
    //       children: [
    //         {
    //           path: "",
    //           name: "jsld_rzlc",
    //           component: () => import("@/views/jsld/rzlc/index.vue"),
    //           meta: { title: "入职流程" },
    //           props: true,
    //         },
    //         {
    //           path: "rzsq",
    //           hidden: true,
    //           name: "jsld_rzlc_rzsq",
    //           component: () => import("@/views/jsld/rzlc/rzsq/index.vue"),
    //           meta: { title: "入职申请" },
    //           props: true,
    //         },
    //       ],
    //     },
    //     {
    //       path: "ldlc",
    //       component: MainDefaultLayout,
    //       meta: { title: "流动流程" },
    //       children: [
    //         {
    //           path: "",
    //           name: "jsld_ldlc",
    //           component: () => import("@/views/jsld/ldlc/index.vue"),
    //           meta: { title: "流动流程" },
    //           props: true,
    //         },
    //         {
    //           path: "ldsq",
    //           hidden: true,
    //           name: "jsld_ldlc_ldsq",
    //           component: () => import("@/views/jsld/ldlc/ldsq/index.vue"),
    //           meta: { title: "流动申请" },
    //           props: true,
    //         },
    //       ],
    //     },
    //
    //     {
    //       path: "lzlc",
    //       component: MainDefaultLayout,
    //       meta: { title: "离职流程" },
    //       children: [
    //         {
    //           path: "",
    //           name: "jsld_lzlc",
    //           component: () => import("@/views/jsld/lzlc/index.vue"),
    //           meta: { title: "离职流程" },
    //           props: true,
    //         },
    //         {
    //           path: "lzsq",
    //           hidden: true,
    //           name: "jsld_lzlc_lzsq",
    //           component: () => import("@/views/jsld/lzlc/lzsq/index.vue"),
    //           meta: { title: "离职申请" },
    //           props: true,
    //         },
    //       ],
    //     },
    //
    //     {
    //       path: "txlc",
    //       component: MainDefaultLayout,
    //       meta: { title: "退休流程" },
    //       children: [
    //         {
    //           path: "",
    //           name: "jsld_txlc",
    //           component: () => import("@/views/jsld/txlc/index.vue"),
    //           meta: { title: "退休流程" },
    //           props: true,
    //         },
    //         {
    //           path: "txsq",
    //           hidden: true,
    //           name: "jsld_txlc_txsq",
    //           component: () => import("@/views/jsld/txlc/txsq/index.vue"),
    //           meta: { title: "退休申请" },
    //           props: true,
    //         },
    //       ],
    //     },
    //     {
    //       path: "zdylc",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "zdylc",
    //           component: () => import("@/views/jsld/zdylc/index.vue"),
    //           meta: { title: "自定义流程" },
    //           props: true,
    //         },
    //       ],
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       meta: { title: "报表统计" },
    //       children: [
    //         {
    //           path: "",
    //           name: "jsld_bbtj",
    //           component: () => import("@/views/jsld/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "jsld_bbtj_bbxq",
    //           component: () => import("@/views/jsld/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/kylxsb",
    //   component: AppLayout,
    //   redirect: "/kylxsb/kylx",
    //   name: "kylxsb",
    //   meta: { title: "科研立项申报", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "kylx",
    //       // name: 'zzjg',
    //       component: () => import("@/views/kylxsb/kylx/index.vue"),
    //       meta: { title: "科研立项" },
    //     },
    //     {
    //       path: "kylb",
    //       // name: 'zzjg',
    //       component: () => import("@/views/kylxsb/kylb/index.vue"),
    //       meta: { title: "科研类别" },
    //     },
    //     {
    //       path: "kyhd",
    //       // name: 'zzjg',
    //       component: () => import("@/views/kylxsb/kyhd/index.vue"),
    //       meta: { title: "科研活动" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "kylxsb_bbtj",
    //           component: () => import("@/views/kylxsb/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "kylxsb_bbtj_bbxq",
    //           component: () => import("@/views/kylxsb/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/jxdydj",
    //   component: AppLayout,
    //   redirect: "/jxdydj/jyxxtz",
    //   name: "jxdydj",
    //   meta: { title: "教学调研登记", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "jyxxtz",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jxdydj/jyxxtz/index.vue"),
    //       meta: { title: "教研消息通知" },
    //     },
    //     {
    //       path: "dyjg",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jxdydj/dyjg/index.vue"),
    //       meta: { title: "调研结果" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "jxdydj_bbtj",
    //           component: () => import("@/views/jxdydj/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "jxdydj_bbtj_bbxq",
    //           component: () => import("@/views/jxdydj/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/cfbtsb",
    //   component: AppLayout,
    //   redirect: "/cfbtsb/gzt",
    //   name: "cfbtsb",
    //   meta: { title: "餐费补贴申报", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "gzt",
    //       // name: 'zzjg',
    //       component: () => import("@/views/cfbtsb/gzt/index.vue"),
    //       meta: { title: "工作台" },
    //     },
    //     {
    //       path: "btlb",
    //       // name: 'zzjg',
    //       component: () => import("@/views/cfbtsb/btlb/index.vue"),
    //       meta: { title: "补贴列表" },
    //     },
    //     {
    //       path: "shsz",
    //       // name: 'zzjg',
    //       component: () => import("@/views/cfbtsb/shsz/index.vue"),
    //       meta: { title: "审核设置" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "cfbtsb_bbtj",
    //           component: () => import("@/views/cfbtsb/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "cfbtsb_bbtj_bbxq",
    //           component: () => import("@/views/cfbtsb/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/jbcfbt",
    //   component: AppLayout,
    //   redirect: "/jbcfbt/gzt",
    //   name: "jbcfbt",
    //   meta: { title: "加班餐费补贴", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "gzt",
    //       component: () => import("@/views/jbcfbt/gzt/index.vue"),
    //       meta: { title: "工作台" },
    //     },
    //     {
    //       path: "gzt_wdsh",
    //       hidden: true,
    //       name: "gzt_wdsh",
    //       component: () => import("@/views/jbcfbt/gzt/wdsh/index.vue"),
    //       meta: { title: "我的审核" },
    //     },
    //     {
    //       path: "gzt_wdsq",
    //       hidden: true,
    //       name: "gzt_wdsq",
    //       component: () => import("@/views/jbcfbt/gzt/wdsq/index.vue"),
    //       meta: { title: "我的申请" },
    //     },
    //     {
    //       path: "jblx",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jbcfbt/jblx/index.vue"),
    //       meta: { title: "加班类型" },
    //     },
    //     {
    //       path: "lxjt",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jbcfbt/lxjt/index.vue"),
    //       meta: { title: "类型津贴" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "jbcfbt_bbtj",
    //           component: () => import("@/views/jbcfbt/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq1/:id",
    //           hidden: true,
    //           name: "cfbtsb_bbtj_bbxq1",
    //           component: () => import("@/views/cfbtsb/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/jysbys",
    //   component: AppLayout,
    //   redirect: "/jysbys/sbys",
    //   name: "jysbys",
    //   meta: { title: "教育设备预算", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "sbys",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jysbys/sbys/index.vue"),
    //       meta: { title: "设备预算" },
    //     },
    //     {
    //       path: "sblxgl",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jysbys/sblxgl/index.vue"),
    //       meta: { title: "设备类别管理" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "jysbys_bbtj",
    //           component: () => import("@/views/jysbys/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "jysbys_bbtj_bbxq",
    //           component: () => import("@/views/jysbys/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/xqyctj",
    //   component: AppLayout,
    //   redirect: "/xqyctj/wcyd",
    //   name: "xqyctj",
    //   meta: { title: "需求预测统计", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "wcyd",
    //       // name: 'zzjg',
    //       component: () => import("@/views/xqyctj/wcyd/index.vue"),
    //       meta: { title: "我参与的" },
    //     },
    //     {
    //       path: "wfqd",
    //       // name: 'zzjg',
    //       component: () => import("@/views/xqyctj/wfqd/index.vue"),
    //       meta: { title: "我发起的" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "xqyctj_bbtj",
    //           component: () => import("@/views/xqyctj/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "xqyctj_bbtj_bbxq",
    //           component: () => import("@/views/xqyctj/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/jkdagl",
    //   component: AppLayout,
    //   redirect: "/jkdngl/sjgl",
    //   name: "jkdagl",
    //   meta: { title: "健康档案管理", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "sjgl",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jkdagl/sjgl/index.vue"),
    //       meta: { title: "数据概览" },
    //     },
    //     {
    //       path: "jzgda",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jkdagl/jzgda/index.vue"),
    //       meta: { title: "教职工档案" },
    //     },
    //     {
    //       path: "xsda",
    //       // name: 'zzjg',
    //       component: () => import("@/views/jkdagl/xsda/index.vue"),
    //       meta: { title: "学生档案" },
    //     },
    //     {
    //       path: "bbtj",
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "jkdagl_bbtj",
    //           component: () => import("@/views/jkdagl/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:id",
    //           hidden: true,
    //           name: "jkdagl_bbtj_bbxq",
    //           component: () => import("@/views/jkdagl/bbtj/bbxq/index.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/qjygl",
    //   component: AppLayout,
    //   redirect: "/qjygl/zyxxlb",
    //   name: "qjygl",
    //   meta: { title: "区教研管理", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "zyxxlb",
    //       // name: 'zzjg',
    //       component: () => import("@/views/qjygl/zyxxlb/index.vue"),
    //       meta: { title: "资源信息列表" },
    //     },
    //     {
    //       path: "zylbgl",
    //       // name: 'zzjg',
    //       component: () => import("@/views/qjygl/zylbgl/index.vue"),
    //       meta: { title: "资源类别管理" },
    //     },
    //     {
    //       path: "zygx",
    //       // name: 'zzjg',
    //       component: () => import("@/views/qjygl/zygx/index.vue"),
    //       meta: { title: "资源共享" },
    //     },
    //   ],
    // },
    // {
    //   path: "/dddx",
    //   component: AppLayout,
    //   redirect: "/dddx/ddrw",
    //   name: "dddx",
    //   meta: { title: "督导督学", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "ddrw",
    //       // name: 'zzjg',
    //       component: () => import("@/views/dddx/ddrw/index.vue"),
    //       meta: { title: "督导任务" },
    //     },
    //     {
    //       path: "ddgzjh/:id",
    //       name: "dddx_ddgzjh",
    //       component: () => import("@/views/dddx/ddgzjh/index.vue"),
    //       meta: { title: "督导工作计划" },
    //       props: true,
    //     },
    //     {
    //       path: "ddgzjl",
    //       name: "dddx_ddgzjl",
    //       component: () => import("@/views/dddx/ddgzjl/index.vue"),
    //       meta: { title: "督导工作记录" },
    //       props: true,
    //     },
    //     {
    //       path: "ddqkfk",
    //       // name: 'zzjg',
    //       component: () => import("@/views/dddx/ddqkfk/index.vue"),
    //       meta: { title: "督导情况反馈" },
    //     },
    //     {
    //       path: "ddzs",
    //       // name: 'zzjg',
    //       component: () => import("@/views/dddx/ddzs/index.vue"),
    //       meta: { title: "督导综述" },
    //     },
    //     {
    //       path: "gzzj",
    //       // name: 'zzjg',
    //       component: () => import("@/views/dddx/gzzj/index.vue"),
    //       meta: { title: "工作总结" },
    //     },
    //   ],
    // },
    // {
    //   path: "/pjkhxt",
    //   component: AppLayout,
    //   redirect: "/pjkhxt/sjgl",
    //   name: "pjkhxt",
    //   meta: { title: "评价考核系统", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "sjgl",
    //       // name: 'zzjg',
    //       component: () => import("@/views/pjkhxt/sjgl/index.vue"),
    //       meta: { title: "数据概览" },
    //     },
    //     {
    //       path: "pjkh",
    //       // name: 'zzjg',
    //       component: () => import("@/views/pjkhxt/pjkh/index.vue"),
    //       meta: { title: "评价考核" },
    //     },
    //   ],
    // },
    // {
    //   path: "/zzjgyqx",
    //   component: AppLayout,
    //   name: "zzjgyqx",
    //   meta: { title: "", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "",
    //       // name: 'zzjg',
    //       component: () => import("@/views/zzjgyqx/index.vue"),
    //       meta: { title: "组织机构与权限" },
    //     },
    //   ],
    // },
    // {
    //   path: "/xxzx",
    //   component: AppLayout,
    //   hidden: true,
    //   children: [
    //     {
    //       path: "",
    //       name: "xxzx",
    //
    //       component: () => import("@/views/xxzx/index.vue"),
    //       meta: { title: "消息中心" },
    //     },
    //   ],
    // },
    // {
    //   path: "/sbcgsq",
    //   component: AppLayout,
    //   redirect: "/sbcgsq/cgxmk",
    //   name: "sbcgsq",
    //   meta: { title: "设备采购申请", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "sbys",
    //       // name: 'zzjg',
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "sbys",
    //           component: () => import("@/views/sbcgsq/sbys/index.vue"),
    //           meta: { title: "设备预算" },
    //           props: true,
    //         },
    //         {
    //           path: "detail/:id",
    //           hidden: true,
    //           name: "sbys_detail",
    //           component: () => import("@/views/sbcgsq/sbys/detail.vue"),
    //           meta: { title: "设备预算/详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //     {
    //       path: "sblxgl",
    //       // name: 'zzjg',
    //       component: () => import("@/views/sbcgsq/sblxgl/index.vue"),
    //       meta: { title: "设备类型管理" },
    //     },
    //     {
    //       path: "cgxmk",
    //       // name: 'zzjg',
    //       component: () => import("@/views/sbcgsq/cgxmk/index.vue"),
    //       meta: { title: "采购项目库" },
    //     },
    //     {
    //       path: "bbtj",
    //       // name: 'zzjg',
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "sbcgsq_bbtj",
    //           component: () => import("@/views/sbcgsq/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:bb_id",
    //           hidden: true,
    //           name: "sbcgsq_bbtj_bbxq",
    //           component: () => import("@/views/sbcgsq/bbtj/detail.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //     {
    //       path: "lcgl",
    //       // name: 'zzjg',
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "lcgl",
    //           component: () => import("@/views/sbcgsq/lcgl/index.vue"),
    //           meta: { title: "流程管理" },
    //           props: true,
    //         },
    //         {
    //           path: "detail/:id",
    //           hidden: true,
    //           name: "lcgl_detail",
    //           component: () => import("@/views/sbcgsq/lcgl/detail.vue"),
    //           meta: { title: "流程管理/详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // {
    //   path: "/hysydgl",
    //   component: AppLayout,
    //   redirect: "/hysydgl/hysyd",
    //   name: "hysydgl",
    //   meta: { title: "会议室预定管理", icon: "el-icon-document" },
    //   children: [
    //     {
    //       path: "hysyd",
    //       // name: 'zzjg',
    //       component: () => import("@/views/hysydgl/hysyd/index.vue"),
    //       meta: { title: "会议室预定" },
    //     },
    //     {
    //       path: "hysyd_detail/:yd_id",
    //       name: "hysyd_detail",
    //       component: () => import("@/views/hysydgl/hysyd/detail.vue"),
    //     },
    //     {
    //       path: "hyjy",
    //       // name: 'zzjg',
    //       component: () => import("@/views/hysydgl/hyjy/index.vue"),
    //       meta: { title: "会议纪要" },
    //     },
    //     {
    //       path: "hyjy_detail/:hyjy_id",
    //       name: "hyjy_detail",
    //       component: () => import("@/views/hysydgl/hyjy/detail.vue"),
    //     },
    //     {
    //       path: "hyjyk",
    //       // name: 'zzjg',
    //       component: () => import("@/views/hysydgl/hyjyk/index.vue"),
    //       meta: { title: "会议纪要库" },
    //     },
    //     {
    //       path: "hysgl",
    //       // name: 'zzjg',
    //       component: () => import("@/views/hysydgl/hysgl/index.vue"),
    //       meta: { title: "会议室管理" },
    //     },
    //     {
    //       path: "bbtj",
    //       // name: 'zzjg',
    //       component: MainDefaultLayout,
    //       children: [
    //         {
    //           path: "",
    //           name: "hysyd_bbtj",
    //           component: () => import("@/views/hysydgl/bbtj/index.vue"),
    //           meta: { title: "报表统计" },
    //           props: true,
    //         },
    //         {
    //           path: "bbxq/:bb_id",
    //           hidden: true,
    //           name: "hysyd_bbtj_bbxq",
    //           component: () => import("@/views/hysydgl/bbtj/detail.vue"),
    //           meta: { title: "报表详情" },
    //           props: true,
    //         },
    //       ],
    //     },
    //   ],
    // },
    // 404 page must be placed at the end !!!
    {path: "*", redirect: "/404", hidden: true},
];

function hasPermission(route, role) {
    if (Array.isArray(route?.meta?.roles)) {
        return route.meta.roles.includes(role);
    } else {
        return true;
    }
}

function handleFilterRoutes(routes, role) {
    const res = [];
    routes.forEach((route) => {
        const tmp = {...route};
        if (hasPermission(tmp, role)) {
            if (tmp.children) {
                tmp.children = handleFilterRoutes(tmp.children, role);
            }
            res.push(tmp);
        }
    });
    return res;
}

// import {user} from "@/stores/user";
//
// var filterRoutes;
// const ifPower = user.power;
// var announceMark = ifPower.announce;
// if (announceMark == 1) {
//     //设定了权限;
//     var aa = filterNewRoutes(allRoutes, ifPower);
//
//     filterRoutes = handleFilterRoutes(aa, user.roleName)
//     console.log(filterRoutes, "9999")
// } else {
//     //没有设定权限
//     filterRoutes = handleFilterRoutes(allRoutes, user.roleName);
// }
//
// var filterRoutes = handleFilterRoutes(allRoutes, user.roleName);
//
// function filterNewRoutes(allRoutes, ifPower) {
//     var temp_routesArr = [];
//     allRoutes.forEach((item) => {
//         const tmp = {...item};
//         if (item.name == "mhgl") {
//             delete item.meta.roles;
//             if (item.children) {
//                 item.children.forEach((itemSec) => {
//                     //将活动公告，通知公告的roles去除
//                     if (itemSec.path == "hdgg" || itemSec.path == "tzgg") {
//                         delete itemSec.meta.roles;
//                     }
//                 });
//             }
//         }
//         temp_routesArr.push(tmp);
//     });
//     return temp_routesArr;
// }
//
const createRouter = () =>
    new Router({
        // mode: 'history', // require service support
        scrollBehavior: () => ({y: 0}),
        routes: allRoutes,
    });

const router = createRouter();
//
// // Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
// export function resetRouter() {
//     const newRouter = createRouter();
//     router.matcher = newRouter.matcher; // reset router
// }

export default router;

/* 
=====================================================================================
=====================================================================================
*/

import getPageTitle from "@/utils/get-page-title";

router.beforeEach(async (to, from, next) => {
    document.title = getPageTitle(to.meta.title);
    console.groupCollapsed(
        `router ${from.meta.title || "新进入"} => ${to.meta.title}`
    );
    console.log("from :>> ", from);
    console.log("to :>> ", to);
    console.groupEnd();
    next();
});
