import axios from 'axios';
import { Message } from 'element-ui'

import { useUserStore } from '@/stores/user'
const { token } = useUserStore()

const service = axios.create({
  baseURL: window.globalVariables.api,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
  },
});

/**请求拦截*/
service.interceptors.request.use(
  (config) => {
    config.data = Object.assign(
      {
        api: 'json',
        issubmit: 1,
        token,
      },
      config.data || {}
    )
    if (config.method === 'get') {
      config.params = Object.assign(
        {
          token,
        },
        config.params || {}
      )
    }
    return config
  },
  (error) => {
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

/**响应拦截*/
service.interceptors.response.use(
  (response, c) => {
    const { code, msg } = response.data
    if (code !== '1') {
      Message.error(msg)
    }
    // console.log('response', response.data)
    // console.groupEnd()
    return response.data
  },
  (error) => {
    console.error('err' + error) // for debug
    return Promise.reject(error)
  }
)

// 上传
export const request = axios.create({
  baseURL: window.globalVariables.api,
  method: 'post',
  timeout: 5000,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded',
  },
})
// 上传的相应拦截
request.interceptors.response.use(
  (response) => {
    const { code, msg } = response.data
    if (code !== '1') {
      Message.error(msg)
    }
    return response.data
  },
  (error) => {
    console.log('err' + error) // for debug
    return Promise.reject(error)
  }
)

/**  
 * GET请求
*/
export let get = (url, params = {}) => {
  return new Promise((resolve, reject) => {
    service.get(url, { params }).then(res => {
      resolve(res)
    })
  })
};


/**
 * POST请求
*/
export let post = (url, params, isFile = false) => {
  let data = null;
  // 如果是文件，转FormData ；不是，就qs.stringify()
  if (isFile) {
      data = new FormData()
      for (let i in params) {
        data.append(i, params[i])
      }
  } else {
      data = params
  }
  //返回
  return new Promise((resolve, reject) => {
    service.post(url, data).then(res => {
          resolve(res)
      })
  })
}


// export default service
